.. autoarchive.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2012 Róbert Čerňanský



.. A section for the AutoArchive package.



AutoArchive
===========

.. automodule:: AutoArchive
   :no-members:



Sub-Packages
------------

.. toctree::
   :maxdepth: 1

   mainf
   archiving
   configuration
   ui
   services



Modules
-------

starter
^^^^^^^

.. automodule:: AutoArchive.starter
.. autodata:: AutoArchive.starter._COMPONENTS



_app_environment
^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._app_environment
.. autoclass:: _AppEnvironment



_meta
^^^^^

.. automodule:: AutoArchive._meta
.. autoclass:: _Meta



_py_additions
^^^^^^^^^^^^^

.. automodule:: AutoArchive._py_additions



_utils
^^^^^^

.. automodule:: AutoArchive._utils
.. autoclass:: _Utils
.. autoclass:: _Constants
